# {{ project_name }} - Project Context

> Auto-generated context document for AI/LLM consumption
> Generated: {{ generated_at.strftime('%Y-%m-%d %H:%M:%S') }}

## Overview

{% if description %}
{{ description }}
{% else %}
This document provides structured context about the {{ project_name }} project.
{% endif %}

## Technology Stack

| Category | Technology |
|----------|------------|
| Language | {{ tech_stack.language }} |
{% if tech_stack.framework %}| Framework | {{ tech_stack.framework }} |
{% endif %}{% if tech_stack.database %}| Database | {{ tech_stack.database }} |
{% endif %}{% if tech_stack.auth %}| Authentication | {{ tech_stack.auth }} |
{% endif %}{% if tech_stack.deployment %}| Deployment | {{ tech_stack.deployment }} |
{% endif %}{% if tech_stack.package_manager %}| Package Manager | {{ tech_stack.package_manager }} |
{% endif %}{% if tech_stack.services %}| Services | {{ tech_stack.services | join(', ') }} |
{% endif %}

## Growth Hubs

{% if growth_hubs %}
The following features have been identified as having growth potential:

{% for hub in growth_hubs %}
### {{ hub.feature_name }}

- **File**: `{{ hub.file_path }}`
- **Intent**: {{ hub.detected_intent }}
- **Confidence**: {{ (hub.confidence_score * 100)|round }}%
{% if hub.entry_point %}- **Entry Point**: `{{ hub.entry_point }}`{% endif %}
{% if hub.growth_potential %}
- **Growth Potential**:
{% for potential in hub.growth_potential %}
  - {{ potential }}
{% endfor %}
{% endif %}

{% endfor %}
{% else %}
No growth hubs have been identified yet.
{% endif %}

## GTM Gaps

{% if gtm_gaps %}
The following go-to-market gaps have been identified:

| Feature | Description | Priority |
|---------|-------------|----------|
{% for gap in gtm_gaps %}
| {{ gap.feature_name }} | {{ gap.description }} | {{ gap.priority }} |
{% endfor %}
{% else %}
No GTM gaps have been identified.
{% endif %}

---

*This context document was generated by skene-growth.*
