"""
Programmatic SEO page generation.

Tools for generating multiple SEO-optimized pages from growth manifests.
"""

from skene_growth.docs.pseo.builder import PSEOBuilder

__all__ = [
    "PSEOBuilder",
]
