# {{ project_name }}

{% if product_overview and product_overview.tagline %}
> {{ product_overview.tagline }}

{% endif %}
{% if product_overview and product_overview.value_proposition %}
{{ product_overview.value_proposition }}
{% elif description %}
{{ description }}
{% endif %}

{% if product_overview and product_overview.target_audience %}
**Built for**: {{ product_overview.target_audience }}
{% endif %}

## Tech Stack

{{ project_name }} is built with:

{% if tech_stack.framework %}- **Framework**: {{ tech_stack.framework }}
{% endif %}- **Language**: {{ tech_stack.language }}
{% if tech_stack.database %}- **Database**: {{ tech_stack.database }}
{% endif %}{% if tech_stack.auth %}- **Authentication**: {{ tech_stack.auth }}
{% endif %}{% if tech_stack.deployment %}- **Deployment**: {{ tech_stack.deployment }}
{% endif %}{% if tech_stack.services %}- **Services**: {{ tech_stack.services | join(', ') }}
{% endif %}

## Features

{% if features %}
{% for feature in features %}
### {{ feature.name }}

{{ feature.description }}

{% if feature.usage_example %}
```
{{ feature.usage_example }}
```
{% endif %}

{% endfor %}
{% elif growth_hubs %}
{% for hub in growth_hubs %}
### {{ hub.feature_name }}

{{ hub.detected_intent }}

{% if hub.growth_potential %}
**Key capabilities:**
{% for potential in hub.growth_potential %}
- {{ potential }}
{% endfor %}
{% endif %}

{% endfor %}
{% else %}
Documentation for features is coming soon.
{% endif %}

## Roadmap

{% if gtm_gaps %}
We're working on the following improvements:

{% for gap in high_priority_gaps %}
- **{{ gap.feature_name }}**: {{ gap.description }}
{% endfor %}

{% for gap in gtm_gaps if gap.priority != "high" %}
- {{ gap.feature_name }}: {{ gap.description }}
{% endfor %}
{% else %}
Check back soon for updates on our roadmap.
{% endif %}

---

*Documentation generated by skene-growth*
